# mypy-boto3-health

[![PyPI - mypy-boto3-health](https://img.shields.io/pypi/v/mypy-boto3-health.svg?color=blue)](https://pypi.org/project/mypy-boto3-health)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-health.svg?color=blue)](https://pypi.org/project/mypy-boto3-health)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Health 1.15.6](https://boto3.amazonaws.com/v1/documentation/api/1.15.6/reference/services/health.html#Health) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.1.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-health](#mypy-boto3-health)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Health` service.

```bash
python -m pip install boto3-stubs[health]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[health]` in your environment: `python -m pip install 'boto3-stubs[health]'`

Both type checking and auto-complete should work for `Health` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[health]` in your environment: `python -m pip install 'boto3-stubs[health]'`

Both type checking and auto-complete should work for `Health` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[health]` in your environment: `python -m pip install 'boto3-stubs[health]'`
- Run `mypy` as usual

Type checking should work for `Health` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[health]` in your environment: `python -m pip install 'boto3-stubs[health]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Health` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`HealthClient` provides annotations for `boto3.client("health")`.

```python
import boto3

from mypy_boto3_health import HealthClient

client: HealthClient = boto3.client("health")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: HealthClient = session.client("health")
```

### Paginators annotations

`mypy_boto3_health.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_health import HealthClient
from mypy_boto3_health.paginator import (
    DescribeAffectedAccountsForOrganizationPaginator,
    DescribeAffectedEntitiesForOrganizationPaginator,
    DescribeAffectedEntitiesPaginator,
    DescribeEventAggregatesPaginator,
    DescribeEventsForOrganizationPaginator,
    DescribeEventsPaginator,
    DescribeEventTypesPaginator,
)

client: HealthClient = boto3.client("health")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_affected_accounts_for_organization_paginator: DescribeAffectedAccountsForOrganizationPaginator = client.get_paginator("describe_affected_accounts_for_organization")
describe_affected_entities_paginator: DescribeAffectedEntitiesPaginator = client.get_paginator("describe_affected_entities")
describe_affected_entities_for_organization_paginator: DescribeAffectedEntitiesForOrganizationPaginator = client.get_paginator("describe_affected_entities_for_organization")
describe_event_aggregates_paginator: DescribeEventAggregatesPaginator = client.get_paginator("describe_event_aggregates")
describe_event_types_paginator: DescribeEventTypesPaginator = client.get_paginator("describe_event_types")
describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
describe_events_for_organization_paginator: DescribeEventsForOrganizationPaginator = client.get_paginator("describe_events_for_organization")
```







### Typed dictionations

`mypy_boto3_health.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_health.type_defs import (
    AffectedEntityTypeDef,
    DateTimeRangeTypeDef,
    DescribeAffectedAccountsForOrganizationResponseTypeDef,
    DescribeAffectedEntitiesForOrganizationResponseTypeDef,
    DescribeAffectedEntitiesResponseTypeDef,
    DescribeEntityAggregatesResponseTypeDef,
    DescribeEventAggregatesResponseTypeDef,
    DescribeEventDetailsForOrganizationResponseTypeDef,
    DescribeEventDetailsResponseTypeDef,
    DescribeEventsForOrganizationResponseTypeDef,
    DescribeEventsResponseTypeDef,
    DescribeEventTypesResponseTypeDef,
    DescribeHealthServiceStatusForOrganizationResponseTypeDef,
    EntityAggregateTypeDef,
    EntityFilterTypeDef,
    EventAccountFilterTypeDef,
    EventAggregateTypeDef,
    EventDescriptionTypeDef,
    EventDetailsErrorItemTypeDef,
    EventDetailsTypeDef,
    EventFilterTypeDef,
    EventTypeDef,
    EventTypeFilterTypeDef,
    EventTypeTypeDef,
    OrganizationAffectedEntitiesErrorItemTypeDef,
    OrganizationEventDetailsErrorItemTypeDef,
    OrganizationEventDetailsTypeDef,
    OrganizationEventFilterTypeDef,
    OrganizationEventTypeDef,
    PaginatorConfigTypeDef,
)

def get_structure() -> AffectedEntityTypeDef:
    return {
      ...
    }
```
